@@ -14,8 +14,9 @@ __version__ = '0.0.1'
 
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
-from .adapter import RequestsAdapter, AiohttpAdapter
-from .enums import SourceLang, TargetLang, SplitSentences, PreserveFormatting, Formality
+from .adapter import AiohttpAdapter, RequestsAdapter
+from .enums import (Formality, PreserveFormatting, SourceLang, SplitSentences,
+                    TargetLang)
 from .translator import Translator
 
 __all__ = [
