@@ -1,8 +1,16 @@
 from enum import Enum
 
+__all__ = [
+    'SourceLang',
+    'TargetLang',
+    'SplitSentences',
+    'PreserveFormatting',
+    'Formality'
+]
+
 
 class StrEnum(Enum):
-    def __str__(self):
+    def __str__(self) -> str:
         return str(self.value)
 
 
@@ -64,12 +72,12 @@ class TargetLang(StrEnum):
     Chinese = 'ZH'
 
 
-class SplitSentences(Enum):
+class SplitSentences(StrEnum):
     enabled = 0
     disabled = 1
 
 
-class PreserveFormatting(Enum):
+class PreserveFormatting(StrEnum):
     respect = 1
     ignore = 2
 
